/*
 * Paraselene
 * Copyright (c) 2009  Akira Terasaki
 * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
 * 利用可能です。
 */
package paraselene.tag;

import paraselene.*;
import java.io.*;
import java.net.*;

/**
 * Aタグ。
 */
public class Anchor extends Tag {
	private static final long serialVersionUID = 2L;

	/**
	 * コンストラクタ。
	 */
	public Anchor() {
		super( "a", false );
	}

	protected Tag newReplica() {
		return new Anchor();
	}

	public void write( PrintWriter w, StringMode mode ) {
		//setHTTPAjaxHandler( "href", "onclick", "return paraselene_agency_a(this,'%s');" );
		makeID();
		super.write( w, mode );
		setHttpAjaxEventListener( w, mode, "paraselene_a_handler(%s,%s)" );

/*
		Page	page = getAssignedPage();
		String	id = getIDAttribute();
		if ( page.isAjax() && isAjaxEnable() && id != null ) {
			Attribute	attr = getAttribute( "href" );
			if ( attr != null && getAttribute( "target" ) == null && getAttribute( "onclick" ) == null ) {
				URIValue	v = (URIValue)attr.get();
				if ( v != null ) {
					if ( v.isParaselenePagePath() ) {
						String	cmd = String.format( "paraselene_a_handler('%s','%s');", id, page.getUniqueKey() );
						page.addOnLoadScript( w, cmd );
					}
				}
			}
		}
*/
	}
}

